==> net.java.html.lib-0.2-sources.jar: net/java/html/lib/PromiseLike.java <==
package net.java.html.lib;
public class PromiseLike<T> extends net.java.html.lib.Objs {
  protected PromiseLike(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<PromiseLike> {
    $Constructor() {
      super(PromiseLike.class);
    }
    @Override
    public PromiseLike create(java.lang.Object obj) {
      return obj == null ? null : new PromiseLike(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static PromiseLike $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  public <TResult> PromiseLike<TResult> then(net.java.html.lib.Function.A1<? super T,? extends net.java.html.lib.Union.A2<TResult,PromiseLike<TResult>>> onfulfilled, net.java.html.lib.Function.A1<? super java.lang.Object,? extends java.lang.Void> onrejected) {
    return (PromiseLike<TResult>)net.java.html.lib.PromiseLike.$as($Typings$.then$406($js(this), /* FunctionType*/$js(onfulfilled), /* FunctionType*/$js(onrejected)));
  }
  public <TResult> PromiseLike<TResult> then() {
    return (PromiseLike<TResult>)net.java.html.lib.PromiseLike.$as($Typings$.then$407($js(this)));
  }
  public <TResult> PromiseLike<TResult> then(net.java.html.lib.Function.A1<? super T,? extends net.java.html.lib.Union.A2<TResult,PromiseLike<TResult>>> onfulfilled) {
    return (PromiseLike<TResult>)net.java.html.lib.PromiseLike.$as($Typings$.then$408($js(this), /* FunctionType*/$js(onfulfilled)));
  }
}

==> net.java.html.lib-0.3-sources.jar: net/java/html/lib/PromiseLike.java <==
package net.java.html.lib;
public class PromiseLike<T> extends net.java.html.lib.Objs {
  protected PromiseLike(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<PromiseLike> {
    $Constructor() {
      super(PromiseLike.class);
    }
    @Override
    public PromiseLike create(java.lang.Object obj) {
      return obj == null ? null : new PromiseLike(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static PromiseLike $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  public <TResult> PromiseLike<TResult> then(net.java.html.lib.Function.A1<? super T,? extends net.java.html.lib.Union.A2<TResult,PromiseLike<TResult>>> onfulfilled, net.java.html.lib.Function.A1<? super java.lang.Object,? extends java.lang.Void> onrejected) {
    return (PromiseLike<TResult>)net.java.html.lib.PromiseLike.$as($Typings$.then$406($js(this), net.java.html.lib.Objs.$js(net.java.html.lib.Function.newFunction(onfulfilled, new Class[] {null})), net.java.html.lib.Objs.$js(net.java.html.lib.Function.newFunction(onrejected, new Class[] {java.lang.Object.class}))));
  }
  public <TResult> PromiseLike<TResult> then() {
    return (PromiseLike<TResult>)net.java.html.lib.PromiseLike.$as($Typings$.then$407($js(this)));
  }
  public <TResult> PromiseLike<TResult> then(net.java.html.lib.Function.A1<? super T,? extends net.java.html.lib.Union.A2<TResult,PromiseLike<TResult>>> onfulfilled) {
    return (PromiseLike<TResult>)net.java.html.lib.PromiseLike.$as($Typings$.then$408($js(this), net.java.html.lib.Objs.$js(net.java.html.lib.Function.newFunction(onfulfilled, new Class[] {null}))));
  }
}
